@@ -21,6 +21,8 @@ from solfege import lessonfile
 from solfege import mpd
 from solfege.exercises import rhythmtapping
 
+from solfege.mpd.requests import MusicRequest
+
 class Teacher(abstract.RhythmAddOnClass, rhythmtapping.Teacher):
     def __init__(self, exname):
         rhythmtapping.Teacher.__init__(self, exname)
@@ -36,10 +38,14 @@ class Teacher(abstract.RhythmAddOnClass, rhythmtapping.Teacher):
         x = len(lexer.m_string)
         retval = []
         for toc, toc_data in lexer:
-            retval.append(float(toc_data.m_duration.get_rat_value()) * 4 / self.m_P.header.bpm * 60)
+            if isinstance(toc_data, mpd.requests.MusicRequest):
+                retval.append(float(toc_data.m_duration.get_rat_value()) * 4 / self.m_P.header.bpm * 60)
+            else:
+                retval[-1] += float(toc_data.m_duration.get_rat_value()) * 4 / self.m_P.header.bpm * 60
         return retval
 
 class Gui(rhythmtapping.Gui, abstract.RhythmAddOnGuiClass):
+    please_tap_str = _("Please tap the rhythm.")
     def __init__(self, teacher):
         rhythmtapping.Gui.__init__(self, teacher)
         self.add_select_elements_gui()
@@ -72,6 +78,7 @@ class Gui(rhythmtapping.Gui, abstract.RhythmAddOnGuiClass):
         self.g_tap.grab_focus()
     def on_start_practise(self):
         self.m_t.m_custom_mode = bool(self.m_t.m_P.header.configurable_rhythm_elements)
+        super(Gui, self).on_start_practise()
         self.m_t.set_elements_variables()
         if self.m_t.m_custom_mode:
             self.update_select_elements_buttons()
@@ -79,4 +86,3 @@ class Gui(rhythmtapping.Gui, abstract.RhythmAddOnGuiClass):
         else:
             self.g_element_frame.hide()
         self.m_t.set_default_header_values()
-        rhythmtapping.Gui.on_start_practise(self)
