@@ -638,7 +638,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         """
         assert teacher.m_exname not in self.box_dict
         self.get_view().hide()
-        m = __import__("solfege.exercises.%s" % teacher.m_exname, fromlist=("solfege.exercises.%s" % teacher.m_exname,), level=0)
+        m = solfege.app.import_module(teacher.m_exname)
         self.add_view(m.Gui(teacher), teacher.m_exname)
     def on_key_press_event(self, widget, event):
         try:
